@@ -20,6 +20,8 @@ package org.apache.doris.spark.cfg;
 public interface ConfigurationOptions {
     // doris fe node address
     String DORIS_FENODES = "doris.fenodes";
+
+    String DORIS_BENODES = "doris.benodes";
     String DORIS_QUERY_PORT = "doris.query.port";
 
     String DORIS_DEFAULT_CLUSTER = "default_cluster";
@@ -123,5 +125,11 @@ public interface ConfigurationOptions {
      * Use automatic redirection of fe without explicitly obtaining the be list
      */
     String DORIS_SINK_AUTO_REDIRECT = "doris.sink.auto-redirect";
-    boolean DORIS_SINK_AUTO_REDIRECT_DEFAULT = false;
+    boolean DORIS_SINK_AUTO_REDIRECT_DEFAULT = true;
+
+    /**
+     * compress_type
+     */
+    String DORIS_SINK_DATA_COMPRESS_TYPE = "doris.sink.properties.compress_type";
+
 }
