@@ -39,6 +39,7 @@ import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.client.methods.HttpPut;
 import org.apache.http.client.methods.HttpRequestBase;
 import org.apache.http.entity.BufferedHttpEntity;
+import org.apache.http.entity.ByteArrayEntity;
 import org.apache.http.entity.InputStreamEntity;
 import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.DefaultRedirectStrategy;
@@ -50,6 +51,7 @@ import org.apache.spark.sql.types.StructType;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.Serializable;
 import java.nio.charset.StandardCharsets;
@@ -70,7 +72,7 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.LockSupport;
 import java.util.function.Consumer;
 import java.util.stream.Collectors;
-
+import java.util.zip.GZIPOutputStream;
 
 /**
  * DorisStreamLoad
@@ -98,7 +100,8 @@ public class DorisStreamLoad implements Serializable {
     private static final long cacheExpireTimeout = 4 * 60;
     private final LoadingCache<String, List<BackendV2.BackendRowV2>> cache;
     private final String fenodes;
-    private final String fileType;
+    private final String benodes;
+    private final DataFormat dataFormat;
     private String FIELD_DELIMITER;
     private final String LINE_DELIMITER;
     private boolean streamingPassthrough = false;
@@ -106,12 +109,14 @@ public class DorisStreamLoad implements Serializable {
     private final Integer txnRetries;
     private final Integer txnIntervalMs;
     private final boolean autoRedirect;
+    private final String compressType;
 
     public DorisStreamLoad(SparkSettings settings) {
         String[] dbTable = settings.getProperty(ConfigurationOptions.DORIS_TABLE_IDENTIFIER).split("\\.");
         this.db = dbTable[0];
         this.tbl = dbTable[1];
         this.fenodes = settings.getProperty(ConfigurationOptions.DORIS_FENODES);
+        this.benodes = settings.getProperty(ConfigurationOptions.DORIS_BENODES);
         String user = settings.getProperty(ConfigurationOptions.DORIS_REQUEST_AUTH_USER);
         String passwd = settings.getProperty(ConfigurationOptions.DORIS_REQUEST_AUTH_PASSWORD);
         this.authEncoded = getAuthEncoded(user, passwd);
@@ -119,16 +124,19 @@ public class DorisStreamLoad implements Serializable {
         this.maxFilterRatio = settings.getProperty(ConfigurationOptions.DORIS_MAX_FILTER_RATIO);
         this.streamLoadProp = getStreamLoadProp(settings);
         cache = CacheBuilder.newBuilder().expireAfterWrite(cacheExpireTimeout, TimeUnit.MINUTES).build(new BackendCacheLoader(settings));
-        fileType = streamLoadProp.getOrDefault("format", "csv");
-        if ("csv".equals(fileType)) {
-            FIELD_DELIMITER = escapeString(streamLoadProp.getOrDefault("column_separator", "\t"));
-            this.addDoubleQuotes = Boolean.parseBoolean(streamLoadProp.getOrDefault("add_double_quotes", "false"));
-            if (addDoubleQuotes) {
-                LOG.info("set add_double_quotes for csv mode, add trim_double_quotes to true for prop.");
-                streamLoadProp.put("trim_double_quotes", "true");
-            }
-        } else if ("json".equalsIgnoreCase(fileType)) {
-            streamLoadProp.put("read_json_by_line", "true");
+        dataFormat = DataFormat.valueOf(streamLoadProp.getOrDefault("format", "csv").toUpperCase());
+        switch (dataFormat) {
+            case CSV:
+                FIELD_DELIMITER = escapeString(streamLoadProp.getOrDefault("column_separator", "\t"));
+                this.addDoubleQuotes = Boolean.parseBoolean(streamLoadProp.getOrDefault("add_double_quotes", "false"));
+                if (addDoubleQuotes) {
+                    LOG.info("set add_double_quotes for csv mode, add trim_double_quotes to true for prop.");
+                    streamLoadProp.put("trim_double_quotes", "true");
+                }
+                break;
+            case JSON:
+                streamLoadProp.put("read_json_by_line", "true");
+                break;
         }
         LINE_DELIMITER = escapeString(streamLoadProp.getOrDefault("line_delimiter", "\n"));
         this.streamingPassthrough = settings.getBooleanProperty(ConfigurationOptions.DORIS_SINK_STREAMING_PASSTHROUGH,
@@ -142,6 +150,7 @@ public class DorisStreamLoad implements Serializable {
 
         this.autoRedirect = settings.getBooleanProperty(ConfigurationOptions.DORIS_SINK_AUTO_REDIRECT,
                 ConfigurationOptions.DORIS_SINK_AUTO_REDIRECT_DEFAULT);
+        compressType=settings.getProperty(ConfigurationOptions.DORIS_SINK_DATA_COMPRESS_TYPE);
     }
 
     public String getLoadUrlStr() {
@@ -217,13 +226,30 @@ public class DorisStreamLoad implements Serializable {
             String loadUrlStr = String.format(loadUrlPattern, getBackend(), db, tbl);
             this.loadUrlStr = loadUrlStr;
             HttpPut httpPut = getHttpPut(label, loadUrlStr, enable2PC, schema);
-            RecordBatchInputStream recodeBatchInputStream = new RecordBatchInputStream(RecordBatch.newBuilder(rows)
-                    .format(fileType)
-                    .sep(FIELD_DELIMITER)
-                    .delim(LINE_DELIMITER)
-                    .schema(schema)
-                    .addDoubleQuotes(addDoubleQuotes).build(), streamingPassthrough);
-            httpPut.setEntity(new InputStreamEntity(recodeBatchInputStream));
+
+            if(StringUtils.isNotEmpty(compressType)){
+                if("gz".equals(compressType.toLowerCase()) && dataFormat.equals(DataFormat.CSV) ){
+                    RecordBatchString recordBatchString = new RecordBatchString(RecordBatch.newBuilder(rows)
+                            .format(dataFormat)
+                            .sep(FIELD_DELIMITER)
+                            .delim(LINE_DELIMITER)
+                            .schema(schema)
+                            .addDoubleQuotes(addDoubleQuotes).build(), streamingPassthrough);
+                    String content = recordBatchString.getContent();
+                    byte[] compressedData = compressByGZ(content);
+                    httpPut.setEntity(new ByteArrayEntity(compressedData));
+                }else{
+                    throw new StreamLoadException("Not support the compress type [" + compressType + "] for the dataformat [" + dataFormat + "]");
+                }
+            }else{
+                RecordBatchInputStream recodeBatchInputStream = new RecordBatchInputStream(RecordBatch.newBuilder(rows)
+                        .format(dataFormat)
+                        .sep(FIELD_DELIMITER)
+                        .delim(LINE_DELIMITER)
+                        .schema(schema)
+                        .addDoubleQuotes(addDoubleQuotes).build(), streamingPassthrough);
+                httpPut.setEntity(new InputStreamEntity(recodeBatchInputStream));
+            }
             HttpResponse httpResponse = httpClient.execute(httpPut);
             loadResponse = new LoadResponse(httpResponse);
         } catch (IOException e) {
@@ -418,7 +444,8 @@ public class DorisStreamLoad implements Serializable {
             return backend.getIp() + ":" + backend.getHttpPort();
         } catch (ExecutionException e) {
             throw new RuntimeException("get backends info fail", e);
-        } catch (IllegalArgumentException e) {
+        }
+        catch (IllegalArgumentException e) {
             throw new RuntimeException("get frontend info fail", e);
         }
     }
@@ -443,7 +470,6 @@ public class DorisStreamLoad implements Serializable {
         public List<BackendV2.BackendRowV2> load(String key) throws Exception {
             return RestService.getBackendRows(settings, LOG);
         }
-
     }
 
     private String generateLoadLabel() {
@@ -492,7 +518,7 @@ public class DorisStreamLoad implements Serializable {
      */
     private void handleStreamPassThrough() {
 
-        if ("json".equalsIgnoreCase(fileType)) {
+        if (dataFormat.equals(DataFormat.JSON)) {
             LOG.info("handle stream pass through, force set read_json_by_line is true for json format");
             streamLoadProp.put("read_json_by_line", "true");
             streamLoadProp.remove("strip_outer_array");
@@ -500,4 +526,19 @@ public class DorisStreamLoad implements Serializable {
 
     }
 
+    /**
+     * compress data by gz compression algorithm
+     */
+    public byte[] compressByGZ(String content) throws IOException{
+        byte[] compressedData;
+        try(ByteArrayOutputStream baos = new ByteArrayOutputStream();
+            GZIPOutputStream gzipOutputStream = new GZIPOutputStream(baos);
+        ){
+            gzipOutputStream.write(content.getBytes("UTF-8"));
+            gzipOutputStream.finish();
+            compressedData = baos.toByteArray();
+        }
+        return compressedData;
+    }
+
 }
